#!/bin/bash

clear
CONFFILE="compil.conf"
if [ ! -z "$1" ]
then
	if [ ! -f "$1" ]
	then
		echo "Le fichier $1 n'existe pas"
		exit 1
	else
		CONFFILE="$1"
	fi
elif [ ! -f $CONFFILE ]
then
	echo "Le fichier $CONFFILE n'existe pas"
	exit 1
fi
# récupération des paramètres
. $CONFFILE

if [ -z "$PROJECT" ] || [ -z "$VERSION" ] #|| [ -z "$SVN_PATH" ] || [ -z "$TAG" ] || [ -z "$REV" ]
then
	echo "configuration invalide"
	exit 1
fi

PROJECT_DIR=$PROJECT-$VERSION
if [ "$SVN_PATH" != "" ];then
    SVN_PATH="https://dev-eole.ac-dijon.fr/$SVN_PATH"
fi

SSH_INL_ACCOUNT="eole@inl"
INL_POOL_PATH="~/mirror/cdimage/local/packages/gutsy/pool/local"
REPOSITORYINL="$SSH_INL_ACCOUNT:$INL_POOL_PATH"
export DEBEMAIL="eole@ac-dijon.fr"
export DEBFULLNAME="Equipe Eole"

SVN_PATH_NEW="https://dev-eole.ac-dijon.fr/Eole2.1/"

Distrib="eole-2.1-dev"

if [ "$SVN_PATH" != "" ]; then

    SVN_EXPORT_PATH="$SVN_PATH/trunk"
    from="(depuis trunk)"

  ##################################

  echo "déplacement des anciennes versions dans old"
  rm -rf $PROJECT_DIR
  if [ ! -d old ]
  then
	mkdir old
  fi
  mv *.build *.changes *.deb *.udeb *.dsc *.diff.gz old 2>/dev/null

  echo "Utilisation du chemin SVN : $SVN_EXPORT_PATH"
  svn export $SVN_EXPORT_PATH $PROJECT_DIR
  if [ ! -d $PROJECT_DIR/debian ]
  then
	echo "le répertoire ${PROJECT_DIR}/debian n'existe pas !"
	exit 1
  fi

  tar --exclude=debian -cvzf ${PROJECT}_${VERSION}.orig.tar.gz $PROJECT_DIR

  # récupération du changelog dans TRUNK
  #svn checkout $SVN_PATH/trunk/debian svn_deb
  #cp svn_deb/changelog $PROJECT_DIR/debian/changelog
 
else

  # version NON SVN !
  echo "déplacement des anciennes versions dans old"
  if [ ! -d old ]
  then
        mkdir old
  fi
  mv *.build *.changes *.deb *.udeb *.dsc *.diff.gz old 2>/dev/null

fi

cd $PROJECT_DIR
debchange -b -v $VERSION-eole1 -D $Distrib --distributor eole "Passage en Gutsy"

debuild -us -uc -sa
if [ $? -ne 0 ]
then
	echo "Erreur de compilation du paquet"
	exit 1
fi
cd ..

# creation du tags a chaque compilation de paquets SVN
echo "SVN_PATH"

if [ "$SVN_PATH" != "" ];then
 	if [ ! -z `echo $SVN_PATH | grep "Eole2/"` ]; then
        	SVN_PATH_NEW=`echo $SVN_PATH | perl -pi -e 's|Eole2|Eole2.1|g'`
		perl -pi -e 's|Eole2|Eole2.1|g' compil.conf
	elif [ ! -z `echo $SVN_PATH | grep "Outils/"` ]; then
        	SVN_PATH_NEW=`echo $SVN_PATH | perl -pi -e 's|Outils|Eole2.1\/outils|g'`
		perl -pi -e 's|Outils|Eole2.1\/outils|g' compil.conf
	else
        	echo "erreur chemin d'origine : $SVN_PATH"
        	exit 1
	fi

  echo "** Creation du trunk dans la branche Eole 2.1"
  
  svn mkdir $SVN_PATH_NEW -m "Creation du repertoire $SVN_PATH_NEW"
  svn export $SVN_PATH/trunk/ projet
  cp -f $PROJECT_DIR/debian/changelog projet/debian
  revision=`head -n 1 projet/debian/changelog | cut -d ' ' -f  2`
  echo "revision : $revision"
  svn import projet $SVN_PATH_NEW/trunk/ -m "Import du project"

  numtags=`echo $revision | awk -F"-" '{print $NF}' | sed -e 's/)$//'`

  echo $numtags

  svn ls $SVN_PATH_NEW/tags/ >/dev/null 2>&1
  if [ "$?" -ne "0" ]; then
      svn mkdir $SVN_PATH_NEW/tags/ -m "** Creation du repertoire tags dans $PROJECT pour $Distrib **"
  fi

  svn ls $SVN_PATH_NEW/branches/ >/dev/null 2>&1
  if [ "$?" -ne "0" ]; then
    svn mkdir $SVN_PATH_NEW/branches/ -m "Creation de la branche pour le project $PROJECT"
  fi

  echo "** Creation du tag $numtags dans $PROJECT pour $Distrib $from **"
  svn cp $SVN_EXPORT_PATH $SVN_PATH_NEW/tags/$numtags -m "** Creation du tag $numtags dans $PROJECT pour $Distrib $from **"

fi

changefile=`ls *.changes`
echo "** Envoi du paquet sur le repository **"
/usr/bin/expect - << EndMark
spawn dput --force eole $changefile
expect "eole@dev-eole.ac-dijon.fr password: "
send "EoleDijon21\r"
expect eof
EndMark

## 26/11/2.17 : TOUT SUR LE CD de Dev à partir d'aujourd'hui !
#if [ $Distrib == 'eole-2.1-dev' ]; then
#
#echo "envoi de tous les paquets sur la machine de compilation (dev)"
#
#debfiles=`ls *.deb *.udeb 2>/dev/null`
#echo "rm -f $INL_POOL_PATH/$PROJECT*" | ssh $SSH_INL_ACCOUNT 2>/dev/null
#echo "mkdir -p $INL_POOL_PATH/${PROJECT:0:1}/$PROJECT;rm -f $INL_POOL_PATH/${PROJECT:0:1}/$PROJECT/*" | ssh $SSH_INL_ACCOUNT 2>/dev/null
## Suppression temporaire pour reorganisation du repository dev-cd
#scp $PROJECT*.dsc $PROJECT*.diff.gz $PROJECT*.changes $PROJECT*.orig.tar.gz $debfiles $SSH_INL_ACCOUNT:$INL_POOL_PATH/${PROJECT:0:1}/$PROJECT/
#fi

exit 0
