# -*- coding: utf-8 -*-
"""test de fichier de configuration
"""
import autopath
from py.test import raises

from os import path as osp

from eolepack import cfgparser
from eolepack import eole_pack

DATA = osp.join(autopath.HERE, 'data')

def test_eolepack():
    cfgfile = osp.join(DATA, 'eolepack.conf')
    cfg = cfgparser.Config(cfgfile=cfgfile, sections=['GLOBAL'])
    assert cfg.cfgparser.sections() == ['INL', 'ECLAIR', 'GLOBAL', 'DEV', 'STABLE']

def test_eolepack_sections():
    cfgfile = osp.join(DATA, 'eolepack2.conf')
    
    raises (NameError, "cfgparser.Config(cfgfile=cfgfile, sections=['GLOBAL'])")


def test_eolepack_variables():
    cfgfile = osp.join(DATA, 'eolepack.conf')
    cfg = cfgparser.Config(cfgfile=cfgfile, sections=['GLOBAL'])
    assert cfg.parse_vars('GLOBAL') == [('SVN_PATH_ORIG', '"https://dev-eole.ac-dijon.fr/Eole2"'), ('DEBEMAIL', '"eole@ac-dijon.fr"')]
    

def test_eolepack_all_variables():
    cfgfile = osp.join(DATA, 'eolepack.conf')
    cfg = cfgparser.Config(cfgfile=cfgfile, sections=['GLOBAL'])
    assert list(cfg.parse_all_vars()) == [('SVN_PATH_ORIG', '"https://dev-eole.ac-dijon.fr/Eole2"'), ('DEBEMAIL', '"eole@ac-dijon.fr"'), ('SSH_ACCOUNT', '"eole@localhost"'), ('POOL_PATH', '"~/mirror/cdimage/local/packages/eoledev/pool/local"')]

def test_eolepack_all_variables():
    cfgfile = osp.join(DATA, 'eolepack3.conf')
    cfg = cfgparser.Config(cfgfile=cfgfile, sections=['GLOBAL'])
    assert list(cfg.parse_all_vars()) == [('SVN_PATH_ORIG', '"https://dev-eole.ac-dijon.fr/Eole2"'), ('DEBEMAIL', '"eole@ac-dijon.fr"'), ('DEBFULLNAME', '"toto"'), ('SSH_ACCOUNT', '"eole@localhost"'), ('POOL_PATH', '"~/mirror/cdimage/local/packages/eoledev/pool/local"')]


def test_requiered_values_eolepack():
    cfgfile = osp.join(DATA, 'eolepack3.conf')
    packvars = eole_pack.read_eolepack_conf_file(cfgfile)
    assert packvars == [('SVN_PATH_ORIG', '"https://dev-eole.ac-dijon.fr/Eole2"'), ('DEBEMAIL', '"eole@ac-dijon.fr"'), ('DEBFULLNAME', '"toto"'), ('SSH_ACCOUNT', '"eole@localhost"'), ('POOL_PATH', '"~/mirror/cdimage/local/packages/eoledev/pool/local"')]


def test_compil_conf():
    cfgfile = osp.join(DATA, 'compil.conf')
    packvars = eole_pack.read_compil_conf_file(cfgfile)
    assert packvars == [('PROJECT', '"eolebase"'), ('SVN_PATH', '"commun/eolebase"'), ('BRANCHES', '"TATA"'), ('VERSION', '"2.0"'), ('TAGS', '"TITI"'), ('REV', '"TOTO"')]
